from .__about__ import (
    __title__,
    __icon__,
    __summary__,
    __uri__,
    __version__,
    __release_date__,
    __author__,
    __email__,
    __license_name__,
    __license_link__,
    __copyright__,
)

__all__ = [
    "__title__",
    "__icon__",
    "__summary__",
    "__uri__",
    "__version__",
    "__release_date__",
    "__author__",
    "__email__",
    "__license_name__",
    "__license_link__",
    "__copyright__",
]
