# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'designer/mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(750, 550)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QtCore.QSize(750, 550))
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setMinimumSize(QtCore.QSize(750, 500))
        self.centralwidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox_settings = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_settings.setMinimumSize(QtCore.QSize(0, 230))
        self.groupBox_settings.setMaximumSize(QtCore.QSize(16777215, 230))
        self.groupBox_settings.setObjectName("groupBox_settings")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox_settings)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox_source = QtWidgets.QGroupBox(self.groupBox_settings)
        self.groupBox_source.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_source.setMaximumSize(QtCore.QSize(16777215, 60))
        self.groupBox_source.setObjectName("groupBox_source")
        self.lineEdit_separator = QtWidgets.QLineEdit(self.groupBox_source)
        self.lineEdit_separator.setGeometry(QtCore.QRect(100, 28, 30, 21))
        self.lineEdit_separator.setMaximumSize(QtCore.QSize(30, 16777215))
        self.lineEdit_separator.setObjectName("lineEdit_separator")
        self.pushButton_separator_change = QtWidgets.QPushButton(self.groupBox_source)
        self.pushButton_separator_change.setGeometry(QtCore.QRect(140, 24, 80, 32))
        self.pushButton_separator_change.setMinimumSize(QtCore.QSize(80, 0))
        self.pushButton_separator_change.setMaximumSize(QtCore.QSize(80, 16777215))
        self.pushButton_separator_change.setObjectName("pushButton_separator_change")
        self.label_separator = QtWidgets.QLabel(self.groupBox_source)
        self.label_separator.setGeometry(QtCore.QRect(13, 28, 70, 20))
        self.label_separator.setMinimumSize(QtCore.QSize(70, 0))
        self.label_separator.setMaximumSize(QtCore.QSize(60, 16777215))
        self.label_separator.setObjectName("label_separator")
        self.verticalLayout_3.addWidget(self.groupBox_source)
        self.groupBox_target = QtWidgets.QGroupBox(self.groupBox_settings)
        self.groupBox_target.setMaximumSize(QtCore.QSize(16777215, 140))
        self.groupBox_target.setObjectName("groupBox_target")
        self.label_target_directory = QtWidgets.QLabel(self.groupBox_target)
        self.label_target_directory.setGeometry(QtCore.QRect(14, 29, 120, 21))
        self.label_target_directory.setMinimumSize(QtCore.QSize(110, 0))
        self.label_target_directory.setMaximumSize(QtCore.QSize(120, 16777215))
        self.label_target_directory.setObjectName("label_target_directory")
        self.lineEdit_target_directory = QtWidgets.QLineEdit(self.groupBox_target)
        self.lineEdit_target_directory.setGeometry(QtCore.QRect(140, 28, 441, 21))
        self.lineEdit_target_directory.setMinimumSize(QtCore.QSize(0, 0))
        self.lineEdit_target_directory.setMaximumSize(QtCore.QSize(450, 16777215))
        self.lineEdit_target_directory.setReadOnly(True)
        self.lineEdit_target_directory.setObjectName("lineEdit_target_directory")
        self.pushButton_target_dir_change = QtWidgets.QPushButton(self.groupBox_target)
        self.pushButton_target_dir_change.setGeometry(QtCore.QRect(610, 24, 80, 32))
        self.pushButton_target_dir_change.setMinimumSize(QtCore.QSize(80, 0))
        self.pushButton_target_dir_change.setMaximumSize(QtCore.QSize(80, 16777215))
        self.pushButton_target_dir_change.setObjectName("pushButton_target_dir_change")
        self.checkBox_suffix_timestamp = QtWidgets.QCheckBox(self.groupBox_target)
        self.checkBox_suffix_timestamp.setGeometry(QtCore.QRect(10, 60, 320, 21))
        self.checkBox_suffix_timestamp.setMinimumSize(QtCore.QSize(300, 0))
        self.checkBox_suffix_timestamp.setMaximumSize(QtCore.QSize(320, 16777215))
        self.checkBox_suffix_timestamp.setObjectName("checkBox_suffix_timestamp")
        self.checkBox_suffix_custom = QtWidgets.QCheckBox(self.groupBox_target)
        self.checkBox_suffix_custom.setGeometry(QtCore.QRect(10, 90, 160, 21))
        self.checkBox_suffix_custom.setMinimumSize(QtCore.QSize(150, 0))
        self.checkBox_suffix_custom.setMaximumSize(QtCore.QSize(160, 16777215))
        self.checkBox_suffix_custom.setObjectName("checkBox_suffix_custom")
        self.lineEdit_suffix_custom_value = QtWidgets.QLineEdit(self.groupBox_target)
        self.lineEdit_suffix_custom_value.setEnabled(True)
        self.lineEdit_suffix_custom_value.setGeometry(QtCore.QRect(170, 90, 160, 21))
        self.lineEdit_suffix_custom_value.setMinimumSize(QtCore.QSize(150, 0))
        self.lineEdit_suffix_custom_value.setMaximumSize(QtCore.QSize(160, 16777215))
        self.lineEdit_suffix_custom_value.setClearButtonEnabled(False)
        self.lineEdit_suffix_custom_value.setObjectName("lineEdit_suffix_custom_value")
        self.verticalLayout_3.addWidget(self.groupBox_target)
        self.verticalLayout.addWidget(self.groupBox_settings)
        self.groupBox_action = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_action.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_action.setObjectName("groupBox_action")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.groupBox_action)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.pushButton_start = QtWidgets.QPushButton(self.groupBox_action)
        self.pushButton_start.setEnabled(True)
        self.pushButton_start.setMinimumSize(QtCore.QSize(80, 0))
        self.pushButton_start.setMaximumSize(QtCore.QSize(80, 16777215))
        self.pushButton_start.setToolTipDuration(-1)
        self.pushButton_start.setStatusTip("")
        self.pushButton_start.setObjectName("pushButton_start")
        self.horizontalLayout_2.addWidget(self.pushButton_start)
        self.pushButton_target_dir_open = QtWidgets.QPushButton(self.groupBox_action)
        self.pushButton_target_dir_open.setEnabled(True)
        self.pushButton_target_dir_open.setMinimumSize(QtCore.QSize(80, 0))
        self.pushButton_target_dir_open.setMaximumSize(QtCore.QSize(80, 16777215))
        self.pushButton_target_dir_open.setObjectName("pushButton_target_dir_open")
        self.horizontalLayout_2.addWidget(self.pushButton_target_dir_open)
        self.verticalLayout.addWidget(self.groupBox_action)
        self.groupBox_progress = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_progress.setMinimumSize(QtCore.QSize(0, 120))
        self.groupBox_progress.setObjectName("groupBox_progress")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.groupBox_progress)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.textBrowser_progress = QtWidgets.QTextBrowser(self.groupBox_progress)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textBrowser_progress.sizePolicy().hasHeightForWidth())
        self.textBrowser_progress.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(10)
        self.textBrowser_progress.setFont(font)
        self.textBrowser_progress.setReadOnly(True)
        self.textBrowser_progress.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByKeyboard|QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextBrowserInteraction|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.textBrowser_progress.setOpenExternalLinks(True)
        self.textBrowser_progress.setObjectName("textBrowser_progress")
        self.horizontalLayout.addWidget(self.textBrowser_progress)
        self.verticalLayout.addWidget(self.groupBox_progress)
        self.progressBar = QtWidgets.QProgressBar(self.centralwidget)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout.addWidget(self.progressBar)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 750, 33))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuAction = QtWidgets.QMenu(self.menubar)
        self.menuAction.setObjectName("menuAction")
        self.menuAbout = QtWidgets.QMenu(self.menubar)
        self.menuAbout.setObjectName("menuAbout")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionExit = QtWidgets.QAction(MainWindow)
        self.actionExit.setObjectName("actionExit")
        self.actionOpen_directory = QtWidgets.QAction(MainWindow)
        self.actionOpen_directory.setObjectName("actionOpen_directory")
        self.actionOpen_file = QtWidgets.QAction(MainWindow)
        self.actionOpen_file.setObjectName("actionOpen_file")
        self.actionStart_conversion = QtWidgets.QAction(MainWindow)
        self.actionStart_conversion.setObjectName("actionStart_conversion")
        self.actionChange_separator = QtWidgets.QAction(MainWindow)
        self.actionChange_separator.setObjectName("actionChange_separator")
        self.actionChange_target_directory = QtWidgets.QAction(MainWindow)
        self.actionChange_target_directory.setObjectName("actionChange_target_directory")
        self.actionOpen_target_directory = QtWidgets.QAction(MainWindow)
        self.actionOpen_target_directory.setObjectName("actionOpen_target_directory")
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionCheck_for_Update = QtWidgets.QAction(MainWindow)
        self.actionCheck_for_Update.setObjectName("actionCheck_for_Update")
        self.actionDocumentation = QtWidgets.QAction(MainWindow)
        self.actionDocumentation.setObjectName("actionDocumentation")
        self.actionGitHub = QtWidgets.QAction(MainWindow)
        self.actionGitHub.setObjectName("actionGitHub")
        self.actionReleases = QtWidgets.QAction(MainWindow)
        self.actionReleases.setObjectName("actionReleases")
        self.actionCheck_Announcements = QtWidgets.QAction(MainWindow)
        self.actionCheck_Announcements.setObjectName("actionCheck_Announcements")
        self.menuFile.addAction(self.actionOpen_file)
        self.menuFile.addAction(self.actionOpen_directory)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menuAction.addAction(self.actionStart_conversion)
        self.menuAction.addSeparator()
        self.menuAction.addAction(self.actionChange_separator)
        self.menuAction.addSeparator()
        self.menuAction.addAction(self.actionChange_target_directory)
        self.menuAction.addAction(self.actionOpen_target_directory)
        self.menuAbout.addAction(self.actionAbout)
        self.menuAbout.addAction(self.actionCheck_for_Update)
        self.menuAbout.addAction(self.actionCheck_Announcements)
        self.menuAbout.addAction(self.actionDocumentation)
        self.menuAbout.addAction(self.actionGitHub)
        self.menuAbout.addAction(self.actionReleases)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuAction.menuAction())
        self.menubar.addAction(self.menuAbout.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.groupBox_settings.setTitle(_translate("MainWindow", "Settings"))
        self.groupBox_source.setTitle(_translate("MainWindow", "Source files"))
        self.lineEdit_separator.setToolTip(_translate("MainWindow", "<html><head/><body><p>Key-in separation sign e.g. ; or ,</p></body></html>"))
        self.pushButton_separator_change.setToolTip(_translate("MainWindow", "<html><head/><body><p>Click to <span style=\" font-weight:600;\">change separation sign</span>.</p></body></html>"))
        self.pushButton_separator_change.setText(_translate("MainWindow", "Change"))
        self.label_separator.setText(_translate("MainWindow", "Separator:"))
        self.groupBox_target.setTitle(_translate("MainWindow", "Target files"))
        self.label_target_directory.setText(_translate("MainWindow", "Target directory:"))
        self.pushButton_target_dir_change.setToolTip(_translate("MainWindow", "<html><head/><body><p>Click to <span style=\" font-weight:600;\">change target directory</span> for output files.</p></body></html>"))
        self.pushButton_target_dir_change.setText(_translate("MainWindow", "Change"))
        self.checkBox_suffix_timestamp.setText(_translate("MainWindow", "add suffix with \"_YYYYMMDD_HHMMSS\""))
        self.checkBox_suffix_custom.setText(_translate("MainWindow", "add custom suffix"))
        self.groupBox_action.setTitle(_translate("MainWindow", "Action"))
        self.pushButton_start.setToolTip(_translate("MainWindow", "<html><head/><body><p>Click to <span style=\" font-weight:600;\">start </span>conversion of selected *.csv files.</p></body></html>"))
        self.pushButton_start.setText(_translate("MainWindow", "Start"))
        self.pushButton_target_dir_open.setToolTip(_translate("MainWindow", "<html><head/><body><p>Click to <span style=\" font-weight:600;\">open target diregtory</span>.</p></body></html>"))
        self.pushButton_target_dir_open.setText(_translate("MainWindow", "Open"))
        self.groupBox_progress.setTitle(_translate("MainWindow", "Progress preview"))
        self.textBrowser_progress.setToolTip(_translate("MainWindow", "<html><head/><body><p>Here you will see whole progress preview for any action taken.</p><p><span style=\" font-style:italic;\">Note: You can mark and copy text from this field.</span></p></body></html>"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuAction.setTitle(_translate("MainWindow", "Action"))
        self.menuAbout.setTitle(_translate("MainWindow", "Help"))
        self.actionExit.setText(_translate("MainWindow", "Exit"))
        self.actionOpen_directory.setText(_translate("MainWindow", "Open directory"))
        self.actionOpen_file.setText(_translate("MainWindow", "Open file\\-s"))
        self.actionStart_conversion.setText(_translate("MainWindow", "Start conversion"))
        self.actionChange_separator.setText(_translate("MainWindow", "Change separator"))
        self.actionChange_target_directory.setText(_translate("MainWindow", "Change target directory"))
        self.actionOpen_target_directory.setText(_translate("MainWindow", "Open target directory"))
        self.actionAbout.setText(_translate("MainWindow", "About"))
        self.actionCheck_for_Update.setText(_translate("MainWindow", "Check for Update"))
        self.actionDocumentation.setText(_translate("MainWindow", "Documentation"))
        self.actionGitHub.setText(_translate("MainWindow", "GitHub"))
        self.actionReleases.setText(_translate("MainWindow", "Releases"))
        self.actionCheck_Announcements.setText(_translate("MainWindow", "Check Announcements"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
